summaryrefslogtreecommitdiffstats
path: root/contrib/amd/amd
diff options
context:
space:
mode:
authorobrien <obrien@FreeBSD.org>1999-01-13 19:23:16 +0000
committerobrien <obrien@FreeBSD.org>1999-01-13 19:23:16 +0000
commit48ce32b887a1c63d23a479560edd101bcc8da00a (patch)
treeaf783f983bbe37aea4e83736c517007ce480d664 /contrib/amd/amd
parentf6d96f9002b701ad54ce6b730e937efc48628725 (diff)
parentc9384f1d982e4695904ef82271714a049cd32827 (diff)
downloadFreeBSD-src-48ce32b887a1c63d23a479560edd101bcc8da00a.zip
FreeBSD-src-48ce32b887a1c63d23a479560edd101bcc8da00a.tar.gz
This commit was generated by cvs2svn to compensate for changes in r42629,
which included commits to RCS files with non-trunk default branches.
Diffstat (limited to 'contrib/amd/amd')
-rw-r--r--contrib/amd/amd/am_ops.c8
-rw-r--r--contrib/amd/amd/amd.h27
-rw-r--r--contrib/amd/amd/amfs_auto.c16
-rw-r--r--contrib/amd/amd/amfs_direct.c4
-rw-r--r--contrib/amd/amd/amfs_error.c4
-rw-r--r--contrib/amd/amd/amfs_host.c6
-rw-r--r--contrib/amd/amd/amfs_inherit.c6
-rw-r--r--contrib/amd/amd/amfs_link.c4
-rw-r--r--contrib/amd/amd/amfs_linkx.c5
-rw-r--r--contrib/amd/amd/amfs_nfsl.c10
-rw-r--r--contrib/amd/amd/amfs_nfsx.c6
-rw-r--r--contrib/amd/amd/amfs_program.c4
-rw-r--r--contrib/amd/amd/amfs_root.c4
-rw-r--r--contrib/amd/amd/amfs_toplvl.c8
-rw-r--r--contrib/amd/amd/amfs_union.c4
-rw-r--r--contrib/amd/amd/amq_svc.c4
-rw-r--r--contrib/amd/amd/autil.c6
-rw-r--r--contrib/amd/amd/clock.c6
-rw-r--r--contrib/amd/amd/conf.c6
-rw-r--r--contrib/amd/amd/conf_parse.y4
-rw-r--r--contrib/amd/amd/conf_tok.l6
-rw-r--r--contrib/amd/amd/info_file.c4
-rw-r--r--contrib/amd/amd/info_hesiod.c4
-rw-r--r--contrib/amd/amd/info_ldap.c6
-rw-r--r--contrib/amd/amd/info_ndbm.c4
-rw-r--r--contrib/amd/amd/info_nis.c8
-rw-r--r--contrib/amd/amd/info_nisplus.c4
-rw-r--r--contrib/amd/amd/info_passwd.c4
-rw-r--r--contrib/amd/amd/info_union.c4
-rw-r--r--contrib/amd/amd/map.c16
-rw-r--r--contrib/amd/amd/mapc.c8
-rw-r--r--contrib/amd/amd/mntfs.c4
-rw-r--r--contrib/amd/amd/nfs_prot_svc.c4
-rw-r--r--contrib/amd/amd/nfs_start.c4
-rw-r--r--contrib/amd/amd/nfs_subr.c13
-rw-r--r--contrib/amd/amd/ops_TEMPLATE.c4
-rw-r--r--contrib/amd/amd/ops_autofs.c31
-rw-r--r--contrib/amd/amd/ops_cachefs.c4
-rw-r--r--contrib/amd/amd/ops_cdfs.c4
-rw-r--r--contrib/amd/amd/ops_efs.c4
-rw-r--r--contrib/amd/amd/ops_lofs.c4
-rw-r--r--contrib/amd/amd/ops_mfs.c6
-rw-r--r--contrib/amd/amd/ops_nfs.c4
-rw-r--r--contrib/amd/amd/ops_nfs3.c6
-rw-r--r--contrib/amd/amd/ops_nullfs.c6
-rw-r--r--contrib/amd/amd/ops_pcfs.c4
-rw-r--r--contrib/amd/amd/ops_tfs.c6
-rw-r--r--contrib/amd/amd/ops_tmpfs.c6
-rw-r--r--contrib/amd/amd/ops_ufs.c4
-rw-r--r--contrib/amd/amd/ops_umapfs.c6
-rw-r--r--contrib/amd/amd/ops_unionfs.c6
-rw-r--r--contrib/amd/amd/ops_xfs.c4
-rw-r--r--contrib/amd/amd/opts.c17
-rw-r--r--contrib/amd/amd/restart.c4
-rw-r--r--contrib/amd/amd/rpc_fwd.c4
-rw-r--r--contrib/amd/amd/sched.c8
-rw-r--r--contrib/amd/amd/srvr_amfs_auto.c4
57 files changed, 196 insertions, 185 deletions
diff --git a/contrib/amd/amd/am_ops.c b/contrib/amd/amd/am_ops.c
index 918c3f1..2a042df 100644
--- a/contrib/amd/amd/am_ops.c
+++ b/contrib/amd/amd/am_ops.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: am_ops.c,v 5.2.2.1 1992/02/09 15:08:17 jsp beta $
+ * $Id: am_ops.c,v 1.2 1998/12/27 06:24:45 ezk Exp $
*
*/
@@ -315,7 +315,7 @@ reverse_option(const char *opt)
* Caller must eventually free the string being returned.
*/
static char *
-merge_opts(char *opts1, char *opts2)
+merge_opts(const char *opts1, const char *opts2)
{
mntent_t mnt2; /* place holder for opts2 */
char *newstr; /* new string to return (malloc'ed) */
@@ -327,7 +327,7 @@ merge_opts(char *opts1, char *opts2)
char *s1 = strdup(opts1); /* copy of opts1 to munge */
/* initialization */
- mnt2.mnt_opts = opts2;
+ mnt2.mnt_opts = (char *) opts2;
newstr = xmalloc(len);
newstr[0] = '\0';
diff --git a/contrib/amd/amd/amd.h b/contrib/amd/amd/amd.h
index 610dfe2..eb21c7e 100644
--- a/contrib/amd/amd/amd.h
+++ b/contrib/amd/amd/amd.h
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: amd.h,v 1.1 1996/01/13 23:23:39 ezk Exp ezk $
+ * $Id: amd.h,v 1.1.1.1 1998/11/05 02:04:51 ezk Exp $
*
*/
@@ -178,18 +178,17 @@ struct mnt_map {
/*
* Mounting a file system may take a significant period of time. The
- * problem is that if this is done in the main process thread then
- * the entire automounter could be blocked, possibly hanging lots of
- * processes on the system. Instead we use a continuation scheme to
- * allow mounts to be attempted in a sub-process. When the sub-process
- * exits we pick up the exit status (by convention a UN*X error number)
- * and continue in a notifier. The notifier gets handed a data structure
- * and can then determine whether the mount was successful or not. If
- * not, it updates the data structure and tries again until there are no
- * more ways to try the mount, or some other permanent error occurs.
- * In the mean time no RPC reply is sent, even after the mount is succesful.
- * We rely on the RPC retry mechanism to resend the lookup request which
- * can then be handled.
+ * problem is that if this is done in the main process thread then the
+ * entire automounter could be blocked, possibly hanging lots of processes
+ * on the system. Instead we use a continuation scheme to allow mounts to
+ * be attempted in a sub-process. When the sub-process exits we pick up the
+ * exit status (by convention a UN*X error number) and continue in a
+ * notifier. The notifier gets handed a data structure and can then
+ * determine whether the mount was successful or not. If not, it updates
+ * the data structure and tries again until there are no more ways to try
+ * the mount, or some other permanent error occurs. In the mean time no RPC
+ * reply is sent, even after the mount is successful. We rely on the RPC
+ * retry mechanism to resend the lookup request which can then be handled.
*/
struct continuation {
char **ivec; /* Current mount info */
diff --git a/contrib/amd/amd/amfs_direct.c b/contrib/amd/amd/amfs_direct.c
index 1558ae0..8df22b1 100644
--- a/contrib/amd/amd/amfs_direct.c
+++ b/contrib/amd/amd/amfs_direct.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: amfs_direct.c,v 1.1 1997-1998/06/30 19:22:30 ezk Exp ezk $
+ * $Id: amfs_direct.c,v 1.1.1.1 1998/11/05 02:04:46 ezk Exp $
*
*/
diff --git a/contrib/amd/amd/amfs_error.c b/contrib/amd/amd/amfs_error.c
index ccb037b..e8fb3c1 100644
--- a/contrib/amd/amd/amfs_error.c
+++ b/contrib/amd/amd/amfs_error.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: amfs_error.c,v 5.2.2.1 1992/02/09 15:08:21 jsp beta $
+ * $Id: amfs_error.c,v 1.1.1.1 1998/11/05 02:04:46 ezk Exp $
*
*/
diff --git a/contrib/amd/amd/amfs_host.c b/contrib/amd/amd/amfs_host.c
index 731c661..e1ec4e9 100644
--- a/contrib/amd/amd/amfs_host.c
+++ b/contrib/amd/amd/amfs_host.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: amfs_host.c,v 5.2.2.2 1992/05/31 16:36:08 jsp Exp $
+ * $Id: amfs_host.c,v 1.1.1.1 1998/11/05 02:04:46 ezk Exp $
*
*/
@@ -347,7 +347,7 @@ amfs_host_fmount(mntfs *mf)
* The original 10 second per try timeout is WAY too large, especially
* if we're only waiting 10 or 20 seconds max for the response.
* That would mean we'd try only once in 10 seconds, and we could
- * lose the transmitt or receive packet, and never try again.
+ * lose the transmit or receive packet, and never try again.
* A 2-second per try timeout here is much more reasonable.
* 09/28/92 Mike Mitchell, mcm@unx.sas.com
*/
diff --git a/contrib/amd/amd/amfs_inherit.c b/contrib/amd/amd/amfs_inherit.c
index e9709bd..442115d 100644
--- a/contrib/amd/amd/amfs_inherit.c
+++ b/contrib/amd/amd/amfs_inherit.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: amfs_inherit.c,v 5.2.2.1 1992/02/09 15:08:26 jsp beta $
+ * $Id: amfs_inherit.c,v 1.1.1.1 1998/11/05 02:04:47 ezk Exp $
*
*/
@@ -119,7 +119,7 @@ amfs_inherit_init(mntfs *mf)
/*
* Take the linked mount point and
- * propogate.
+ * propagate.
*/
static mntfs *
amfs_inherit_inherit(mntfs *mf)
diff --git a/contrib/amd/amd/amfs_link.c b/contrib/amd/amd/amfs_link.c
index 251c5eb..0daa334 100644
--- a/contrib/amd/amd/amfs_link.c
+++ b/contrib/amd/amd/amfs_link.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: amfs_link.c,v 5.2.2.1 1992/02/09 15:09:04 jsp beta $
+ * $Id: amfs_link.c,v 1.1.1.1 1998/11/05 02:04:47 ezk Exp $
*
*/
diff --git a/contrib/amd/amd/amfs_linkx.c b/contrib/amd/amd/amfs_linkx.c
index e46206f..045f797 100644
--- a/contrib/amd/amd/amfs_linkx.c
+++ b/contrib/amd/amd/amfs_linkx.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: amfs_linkx.c,v 5.2.2.1 1992/02/09 15:09:04 jsp beta $
+ * $Id: amfs_linkx.c,v 1.1.1.1 1998/11/05 02:04:47 ezk Exp $
*
*/
@@ -101,4 +101,3 @@ amfs_linkx_mount(am_node *mp)
return 0;
}
-
diff --git a/contrib/amd/amd/amfs_nfsl.c b/contrib/amd/amd/amfs_nfsl.c
index 8132afd..55e5c75 100644
--- a/contrib/amd/amd/amfs_nfsl.c
+++ b/contrib/amd/amd/amfs_nfsl.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: amfs_nfsl.c,v 5.2.2.3 1992/08/02 10:42:21 jsp Exp $
+ * $Id: amfs_nfsl.c,v 1.2 1998/12/27 06:24:45 ezk Exp $
*
*/
@@ -99,7 +99,7 @@ amfs_nfsl_match(am_opts *fo)
struct stat stb;
if (!cp || !ho) {
- plog(XLOG_USER, "amfs_nfsl: nost $fs and $rhost must be specified");
+ plog(XLOG_USER, "amfs_nfsl: host $fs and $rhost must be specified");
return NULL;
}
@@ -109,7 +109,7 @@ amfs_nfsl_match(am_opts *fo)
* If link value exists (or same host), then perform amfs_link_match(),
* same as for linkx.
*/
- if (!STRCEQ(ho, hostname)) {
+ if (!STRCEQ(ho, am_get_hostname())) {
plog(XLOG_INFO, "amfs_nfsl: \"%s\" is not local host, using type:=nfs", ho);
return nfs_match(fo);
} else if (lstat(cp, &stb) < 0) {
@@ -228,7 +228,7 @@ amfs_nfsl_ffserver(mntfs *mf)
* If link value exists (or same host), then perform
* find_amfs_auto_srvr(), same as for linkx.
*/
- if (!STREQ(ho, hostname) || lstat(cp, &stb) < 0) {
+ if (!STRCEQ(ho, am_get_hostname()) || lstat(cp, &stb) < 0) {
return find_nfs_srvr(mf);
} else {
mf->mf_flags |= MFF_NFSLINK;
diff --git a/contrib/amd/amd/amfs_nfsx.c b/contrib/amd/amd/amfs_nfsx.c
index 272e10d..e67e8f5 100644
--- a/contrib/amd/amd/amfs_nfsx.c
+++ b/contrib/amd/amd/amfs_nfsx.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: amfs_linxx.c,v 5.2.2.3 1992/05/31 16:13:07 jsp Exp $
+ * $Id: amfs_nfsx.c,v 1.1.1.1 1998/11/05 02:04:47 ezk Exp $
*
*/
@@ -463,7 +463,7 @@ amfs_nfsx_fumount(mntfs *mf)
* If this node has not been messed with
* and there has been no error so far
* then try and unmount.
- * If an error had occured then zero
+ * If an error had occurred then zero
* the error code so that the remount
* only tries to unmount those nodes
* which had been successfully unmounted.
diff --git a/contrib/amd/amd/amfs_program.c b/contrib/amd/amd/amfs_program.c
index 2bd0778..04d7c54 100644
--- a/contrib/amd/amd/amfs_program.c
+++ b/contrib/amd/amd/amfs_program.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: amfs_program.c,v 5.2.2.1 1992/02/09 15:08:56 jsp beta $
+ * $Id: amfs_program.c,v 1.1.1.1 1998/11/05 02:04:47 ezk Exp $
*
*/
diff --git a/contrib/amd/amd/amfs_root.c b/contrib/amd/amd/amfs_root.c
index 3c1cd17..e2bd371 100644
--- a/contrib/amd/amd/amfs_root.c
+++ b/contrib/amd/amd/amfs_root.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: amfs_root.c,v 1.1 1997-1998/06/30 19:22:30 ezk Exp ezk $
+ * $Id: amfs_root.c,v 1.1.1.1 1998/11/05 02:04:47 ezk Exp $
*
*/
diff --git a/contrib/amd/amd/amfs_toplvl.c b/contrib/amd/amd/amfs_toplvl.c
index f36c66f..e10c6a1 100644
--- a/contrib/amd/amd/amfs_toplvl.c
+++ b/contrib/amd/amd/amfs_toplvl.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: amfs_toplvl.c,v 1.1 1997-1998/06/30 19:22:30 ezk Exp ezk $
+ * $Id: amfs_toplvl.c,v 1.2 1998/12/27 06:24:45 ezk Exp $
*
*/
@@ -158,8 +158,8 @@ mount_amfs_toplvl(char *dir, char *opts)
* Make a ``hostname'' string for the kernel
*/
sprintf(fs_hostname, "pid%ld@%s:%s",
- (long) (foreground ? mypid : getppid()),
- hostname,
+ (long) (foreground ? am_mypid : getppid()),
+ am_get_hostname(),
dir);
/*
* Most kernels have a name length restriction (64 bytes)...
diff --git a/contrib/amd/amd/amfs_union.c b/contrib/amd/amd/amfs_union.c
index 95fc8fd..df494ac 100644
--- a/contrib/amd/amd/amfs_union.c
+++ b/contrib/amd/amd/amfs_union.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: amfs_union.c,v 1.1 1997-1998/06/30 19:22:30 ezk Exp ezk $
+ * $Id: amfs_union.c,v 1.1.1.1 1998/11/05 02:04:47 ezk Exp $
*
*/
diff --git a/contrib/amd/amd/amq_svc.c b/contrib/amd/amd/amq_svc.c
index 5e4c9fd..bdb1c16 100644
--- a/contrib/amd/amd/amq_svc.c
+++ b/contrib/amd/amd/amq_svc.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: amq_svc.c,v 5.2.2.1 1992/02/09 15:09:26 jsp beta $
+ * $Id: amq_svc.c,v 1.1.1.1 1998/11/05 02:04:47 ezk Exp $
*
*/
diff --git a/contrib/amd/amd/autil.c b/contrib/amd/amd/autil.c
index ca089bd..00ca8ea 100644
--- a/contrib/amd/amd/autil.c
+++ b/contrib/amd/amd/autil.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: autil.c,v 5.2.2.2 1992/03/07 17:52:06 jsp Exp $
+ * $Id: autil.c,v 1.2 1998/12/27 06:24:46 ezk Exp $
*
*/
@@ -393,7 +393,7 @@ top:
goto top;
}
if (pid == 0) { /* child process (foreground==false) */
- mypid = getpid();
+ am_set_mypid();
foreground = 0;
} else { /* parent process, has one more child */
NumChild++;
diff --git a/contrib/amd/amd/clock.c b/contrib/amd/amd/clock.c
index 3c0494a..270401a 100644
--- a/contrib/amd/amd/clock.c
+++ b/contrib/amd/amd/clock.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,14 +38,14 @@
*
* %W% (Berkeley) %G%
*
- * $Id: clock.c,v 5.2.2.1 1992/02/09 15:08:20 jsp beta $
+ * $Id: clock.c,v 1.1.1.1 1998/11/05 02:04:47 ezk Exp $
*
*/
/*
* Callouts.
*
- * Modelled on kernel object of the same name.
+ * Modeled on kernel object of the same name.
* See usual references.
*
* Use of a heap-based mechanism was rejected:
diff --git a/contrib/amd/amd/conf.c b/contrib/amd/amd/conf.c
index 0ec3259..109d005 100644
--- a/contrib/amd/amd/conf.c
+++ b/contrib/amd/amd/conf.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: conf.c,v 5.2.2.1 1992/02/09 15:08:23 jsp beta $
+ * $Id: conf.c,v 1.2 1998/12/27 06:24:46 ezk Exp $
*
*/
@@ -373,7 +373,7 @@ gopt_debug_options(const char *val)
return 0;
#else /* not DEBUG */
fprintf(stderr, "%s: not compiled with DEBUG option -- sorry.\n",
- progname);
+ am_get_progname());
return 1;
#endif /* not DEBUG */
}
diff --git a/contrib/amd/amd/conf_parse.y b/contrib/amd/amd/conf_parse.y
index 2a9877a..c34062b 100644
--- a/contrib/amd/amd/conf_parse.y
+++ b/contrib/amd/amd/conf_parse.y
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: conf_parse.y,v 5.2.2.1 1992/02/09 15:09:35 jsp beta $
+ * $Id: conf_parse.y,v 1.1.1.1 1998/11/05 02:04:51 ezk Exp $
*
*/
diff --git a/contrib/amd/amd/conf_tok.l b/contrib/amd/amd/conf_tok.l
index 0ec067b..7128a2a 100644
--- a/contrib/amd/amd/conf_tok.l
+++ b/contrib/amd/amd/conf_tok.l
@@ -18,7 +18,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -39,7 +39,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: conf_tok.l,v 5.2.2.1 1992/02/09 15:09:36 jsp beta $
+ * $Id: conf_tok.l,v 1.1.1.1 1998/11/05 02:04:51 ezk Exp $
*
*/
@@ -70,7 +70,7 @@
#endif /* ECHO */
/*
- * There are some things that need to be defined only if useing GNU flex.
+ * There are some things that need to be defined only if using GNU flex.
* These must not be defined if using standard lex
*/
#ifdef FLEX_SCANNER
diff --git a/contrib/amd/amd/info_file.c b/contrib/amd/amd/info_file.c
index 55c24bd..1bd9c62 100644
--- a/contrib/amd/amd/info_file.c
+++ b/contrib/amd/amd/info_file.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: info_file.c,v 5.2.2.1 1992/02/09 15:08:28 jsp beta $
+ * $Id: info_file.c,v 1.1.1.1 1998/11/05 02:04:49 ezk Exp $
*
*/
diff --git a/contrib/amd/amd/info_hesiod.c b/contrib/amd/amd/info_hesiod.c
index a4607e1..88de89b 100644
--- a/contrib/amd/amd/info_hesiod.c
+++ b/contrib/amd/amd/info_hesiod.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: info_hesiod.c,v 1.1 1997-1998/07/11 08:34:52 danny Exp danny $
+ * $Id: info_hesiod.c,v 1.1.1.1 1998/11/05 02:04:49 ezk Exp $
*
*/
diff --git a/contrib/amd/amd/info_ldap.c b/contrib/amd/amd/info_ldap.c
index e2f0367..a5f1d75 100644
--- a/contrib/amd/amd/info_ldap.c
+++ b/contrib/amd/amd/info_ldap.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: info_ldap.c,v 5.2.2.1 1992/02/09 15:08:29 jsp beta $
+ * $Id: info_ldap.c,v 1.1.1.1 1998/11/05 02:04:49 ezk Exp $
*
*/
@@ -263,7 +263,7 @@ amu_ldap_rebind(ALD *a)
return (0);
}
}
- plog(XLOG_WARNING, "Exausted list of ldap servers, looping.\n");
+ plog(XLOG_WARNING, "Exhausted list of ldap servers, looping.\n");
}
plog(XLOG_USER, "Unable to (re)bind to any ldap hosts\n");
diff --git a/contrib/amd/amd/info_ndbm.c b/contrib/amd/amd/info_ndbm.c
index 0b93fa6..d8fd39c 100644
--- a/contrib/amd/amd/info_ndbm.c
+++ b/contrib/amd/amd/info_ndbm.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: info_ndbm.c,v 5.2.2.1 1992/02/09 15:08:31 jsp beta $
+ * $Id: info_ndbm.c,v 1.1.1.1 1998/11/05 02:04:49 ezk Exp $
*
*/
diff --git a/contrib/amd/amd/info_nis.c b/contrib/amd/amd/info_nis.c
index 237f6f5..2e9a0b7 100644
--- a/contrib/amd/amd/info_nis.c
+++ b/contrib/amd/amd/info_nis.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: info_nis.c,v 5.2.2.1 1992/02/09 15:08:32 jsp beta $
+ * $Id: info_nis.c,v 1.1.1.1 1998/11/05 02:04:49 ezk Exp $
*
*/
@@ -228,7 +228,7 @@ nis_search(mnt_map *m, char *map, char *key, char **val, time_t *tp)
YP_ORDER_OUTORDER_TYPE order;
/*
- * Make sure domain initialised
+ * Make sure domain initialized
*/
if (!gopt.nis_domain) {
int error = determine_nis_domain();
@@ -341,7 +341,7 @@ nis_mtime(mnt_map *m, char *map, time_t *tp)
* alternate code which avoids a bug in yp_all(). The bug in yp_all() is
* that it does not close a TCP connection to ypserv, and this ypserv runs
* out of open filedescriptors, getting into an infinite loop, thus all YP
- * clients enevtually unbind and hang too.
+ * clients eventually unbind and hang too.
*
* Systems known to be plagued with this bug:
* earlier SunOS 4.x
diff --git a/contrib/amd/amd/info_nisplus.c b/contrib/amd/amd/info_nisplus.c
index 71f29e9..bf681ac 100644
--- a/contrib/amd/amd/info_nisplus.c
+++ b/contrib/amd/amd/info_nisplus.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: info_nisplus.c,v 5.2.2.1 1992/02/09 15:08:32 jsp beta $
+ * $Id: info_nisplus.c,v 1.1.1.1 1998/11/05 02:04:49 ezk Exp $
*
*/
diff --git a/contrib/amd/amd/info_passwd.c b/contrib/amd/amd/info_passwd.c
index 32d92f4..d27c9b3 100644
--- a/contrib/amd/amd/info_passwd.c
+++ b/contrib/amd/amd/info_passwd.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: info_passwd.c,v 5.2.2.1 1992/02/09 15:08:33 jsp beta $
+ * $Id: info_passwd.c,v 1.1.1.1 1998/11/05 02:04:49 ezk Exp $
*
*/
diff --git a/contrib/amd/amd/info_union.c b/contrib/amd/amd/info_union.c
index 7f757f9..00c254d 100644
--- a/contrib/amd/amd/info_union.c
+++ b/contrib/amd/amd/info_union.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: info_union.c,v 5.2.2.1 1992/02/09 15:08:34 jsp beta $
+ * $Id: info_union.c,v 1.1.1.1 1998/11/05 02:04:50 ezk Exp $
*
*/
diff --git a/contrib/amd/amd/map.c b/contrib/amd/amd/map.c
index 20320d9..20e23c0 100644
--- a/contrib/amd/amd/map.c
+++ b/contrib/amd/amd/map.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: map.c,v 5.2.2.2 1992/08/02 10:42:21 jsp Exp $
+ * $Id: map.c,v 1.2 1998/12/27 06:24:47 ezk Exp $
*
*/
@@ -134,7 +134,7 @@ exported_ap_realloc_map(int nsize)
* Allocate a new mount slot and create
* a new node.
* Fills in the map number of the node,
- * but leaves everything else uninitialised.
+ * but leaves everything else uninitialized.
*/
am_node *
exported_ap_alloc(void)
@@ -297,7 +297,7 @@ mk_fattr(am_node *mp, nfsftype vntype)
/*
- * Initialise an allocated mount node.
+ * Initialize an allocated mount node.
* It is assumed that the mount node was b-zero'd
* before getting here so anything that would
* be set to zero isn't done here.
@@ -371,7 +371,7 @@ fh_to_mp3(am_nfs_fh *fhp, int *rp, int c_or_d)
* from an old kernel cached filehandle
* which is now out of date.
*/
- if (fp->fhh_pid != mypid)
+ if (fp->fhh_pid != am_mypid)
goto drop;
/*
@@ -511,7 +511,7 @@ mp_to_fh(am_node *mp, am_nfs_fh *fhp)
/*
* Take the process id
*/
- fp->fhh_pid = mypid;
+ fp->fhh_pid = am_mypid;
/*
* ... the map number
@@ -726,7 +726,7 @@ make_root_node(void)
root_node->am_mnt = root_mnt;
/*
- * Initialise the root
+ * Initialize the root
*/
if (root_mnt->mf_ops->fs_init)
(*root_mnt->mf_ops->fs_init) (root_mnt);
@@ -893,7 +893,7 @@ free_map_if_success(int rc, int term, voidp closure)
mf->mf_flags &= ~MFF_UNMOUNTING;
/*
- * If a timeout was defered because the underlying filesystem
+ * If a timeout was deferred because the underlying filesystem
* was busy then arrange for a timeout as soon as possible.
*/
if (mf->mf_flags & MFF_WANTTIMO) {
diff --git a/contrib/amd/amd/mapc.c b/contrib/amd/amd/mapc.c
index 51ec7e1..70ebf3a 100644
--- a/contrib/amd/amd/mapc.c
+++ b/contrib/amd/amd/mapc.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: mapc.c,v 5.2.2.2 1992/08/02 10:42:21 jsp Exp $
+ * $Id: mapc.c,v 1.1.1.1 1998/11/05 02:04:48 ezk Exp $
*
*/
@@ -113,7 +113,7 @@ static char wildcard[] = "*";
typedef struct map_type map_type;
struct map_type {
char *name; /* Name of this map type */
- init_fn *init; /* Initialisation */
+ init_fn *init; /* Initialization */
reload_fn *reload; /* Reload or fill */
isup_fn *isup; /* Is service up or not? (1=up, 0=down) */
search_fn *search; /* Search for new entry */
@@ -578,7 +578,7 @@ mapc_create(char *map, char *opt, const char *type)
default:
plog(XLOG_USER, "Ambiguous map cache type \"%s\"; using \"inc\"", opt);
alloc = MAPC_INC;
- /* fallthrough... */
+ /* fall-through... */
case MAPC_NONE:
case MAPC_INC:
case MAPC_ROOT:
diff --git a/contrib/amd/amd/mntfs.c b/contrib/amd/amd/mntfs.c
index 31fa331..4168974 100644
--- a/contrib/amd/amd/mntfs.c
+++ b/contrib/amd/amd/mntfs.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: mntfs.c,v 5.2.2.2 1992/08/02 10:42:21 jsp Exp $
+ * $Id: mntfs.c,v 1.1.1.1 1998/11/05 02:04:48 ezk Exp $
*
*/
diff --git a/contrib/amd/amd/nfs_prot_svc.c b/contrib/amd/amd/nfs_prot_svc.c
index e2b1c70..42b24f5 100644
--- a/contrib/amd/amd/nfs_prot_svc.c
+++ b/contrib/amd/amd/nfs_prot_svc.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: nfs_prot_svc.c,v 5.2.2.1 1992/02/09 15:09:30 jsp beta $
+ * $Id: nfs_prot_svc.c,v 1.1.1.1 1998/11/05 02:04:48 ezk Exp $
*
*/
diff --git a/contrib/amd/amd/nfs_start.c b/contrib/amd/amd/nfs_start.c
index e5740f6..d32e8d7 100644
--- a/contrib/amd/amd/nfs_start.c
+++ b/contrib/amd/amd/nfs_start.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: nfs_start.c,v 5.2.2.1 1992/02/09 15:08:51 jsp beta $
+ * $Id: nfs_start.c,v 1.1.1.1 1998/11/05 02:04:48 ezk Exp $
*
*/
diff --git a/contrib/amd/amd/nfs_subr.c b/contrib/amd/amd/nfs_subr.c
index 3de0861..65bcc0d 100644
--- a/contrib/amd/amd/nfs_subr.c
+++ b/contrib/amd/amd/nfs_subr.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: nfs_subr.c,v 5.2.2.1 1992/02/09 15:08:53 jsp beta $
+ * $Id: nfs_subr.c,v 1.1.1.1 1998/11/05 02:04:48 ezk Exp $
*
*/
@@ -141,7 +141,7 @@ nfsproc_getattr_2_svc(am_nfs_fh *argp, struct svc_req *rqstp)
#ifndef MNT2_NFS_OPT_SYMTTL
/*
* This code is needed to defeat Solaris 2.4's (and newer) symlink values
- * cache. It forces the last-modifed time of the symlink to be current.
+ * cache. It forces the last-modified time of the symlink to be current.
* It is not needed if the O/S has an nfs flag to turn off the
* symlink-cache at mount time (such as Irix 5.x and 6.x). -Erez.
*/
@@ -211,6 +211,13 @@ nfsproc_lookup_2_svc(nfsdiropargs *argp, struct svc_req *rqstp)
}
res.dr_status = nfs_error(error);
} else {
+ /*
+ * XXX: EXPERIMENTAL! Delay unmount of what was looked up. This
+ * should reduce the chance for race condition between unmounting an
+ * entry synchronously, and re-mounting it asynchronously.
+ */
+ if (ap->am_ttl < mp->am_ttl)
+ ap->am_ttl = mp->am_ttl;
mp_to_fh(ap, &res.dr_u.dr_drok_u.drok_fhandle);
res.dr_u.dr_drok_u.drok_attributes = ap->am_fattr;
res.dr_status = NFS_OK;
diff --git a/contrib/amd/amd/ops_TEMPLATE.c b/contrib/amd/amd/ops_TEMPLATE.c
index 7a60206..e8e889b 100644
--- a/contrib/amd/amd/ops_TEMPLATE.c
+++ b/contrib/amd/amd/ops_TEMPLATE.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: ops_TEMPLATE.c,v 5.2.2.3 1992/08/02 10:42:21 jsp Exp $
+ * $Id: ops_TEMPLATE.c,v 1.1.1.1 1998/11/05 02:04:51 ezk Exp $
*
*/
diff --git a/contrib/amd/amd/ops_cachefs.c b/contrib/amd/amd/ops_cachefs.c
index 0c40085..40ca356 100644
--- a/contrib/amd/amd/ops_cachefs.c
+++ b/contrib/amd/amd/ops_cachefs.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: ops_cachefs.c,v 5.2.2.3 1992/08/02 10:42:21 jsp Exp $
+ * $Id: ops_cachefs.c,v 1.1.1.1 1998/11/05 02:04:50 ezk Exp $
*
*/
diff --git a/contrib/amd/amd/ops_cdfs.c b/contrib/amd/amd/ops_cdfs.c
index 3a143e2..05de461 100644
--- a/contrib/amd/amd/ops_cdfs.c
+++ b/contrib/amd/amd/ops_cdfs.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: ops_cdfs.c,v 5.2.2.1 1992/02/09 15:09:08 jsp beta $
+ * $Id: ops_cdfs.c,v 1.1.1.1 1998/11/05 02:04:50 ezk Exp $
*
*/
diff --git a/contrib/amd/amd/ops_efs.c b/contrib/amd/amd/ops_efs.c
index 4f915f7..095c2d4 100644
--- a/contrib/amd/amd/ops_efs.c
+++ b/contrib/amd/amd/ops_efs.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: ops_efs.c,v 5.2.2.1 1992/02/09 15:09:08 jsp beta $
+ * $Id: ops_efs.c,v 1.1.1.1 1998/11/05 02:04:50 ezk Exp $
*
*/
diff --git a/contrib/amd/amd/ops_lofs.c b/contrib/amd/amd/ops_lofs.c
index 6555db5..9331bf6 100644
--- a/contrib/amd/amd/ops_lofs.c
+++ b/contrib/amd/amd/ops_lofs.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: ops_lofs.c,v 5.2.2.1 1992/02/09 15:09:08 jsp beta $
+ * $Id: ops_lofs.c,v 1.1.1.1 1998/11/05 02:04:50 ezk Exp $
*
*/
diff --git a/contrib/amd/amd/ops_mfs.c b/contrib/amd/amd/ops_mfs.c
index f93c30b..b6a32ba 100644
--- a/contrib/amd/amd/ops_mfs.c
+++ b/contrib/amd/amd/ops_mfs.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: ops_mfs.c,v 5.2.2.3 1992/08/02 10:42:21 jsp Exp $
+ * $Id: ops_mfs.c,v 1.1.1.1 1998/11/05 02:04:50 ezk Exp $
*
*/
@@ -52,4 +52,4 @@
#include <am_defs.h>
#include <amd.h>
-/* FEEL FREE TO INPLEMENT THIS... :-) */
+/* FEEL FREE TO IMPLEMENT THIS... :-) */
diff --git a/contrib/amd/amd/ops_nfs.c b/contrib/amd/amd/ops_nfs.c
index a7006b4..bad0bd9 100644
--- a/contrib/amd/amd/ops_nfs.c
+++ b/contrib/amd/amd/ops_nfs.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: ops_nfs.c,v 5.2.2.3 1992/08/02 10:42:21 jsp Exp $
+ * $Id: ops_nfs.c,v 1.1.1.1 1998/11/05 02:04:50 ezk Exp $
*
*/
diff --git a/contrib/amd/amd/ops_nfs3.c b/contrib/amd/amd/ops_nfs3.c
index 5db0713..19d6533 100644
--- a/contrib/amd/amd/ops_nfs3.c
+++ b/contrib/amd/amd/ops_nfs3.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: ops_nfs3.c,v 5.2.2.3 1992/08/02 10:42:21 jsp Exp $
+ * $Id: ops_nfs3.c,v 1.1.1.1 1998/11/05 02:04:50 ezk Exp $
*
*/
@@ -52,4 +52,4 @@
#include <am_defs.h>
#include <amd.h>
-/* FEEL FREE TO INPLEMENT THIS... :-) */
+/* FEEL FREE TO IMPLEMENT THIS... :-) */
diff --git a/contrib/amd/amd/ops_nullfs.c b/contrib/amd/amd/ops_nullfs.c
index bf2009f..6f560a8 100644
--- a/contrib/amd/amd/ops_nullfs.c
+++ b/contrib/amd/amd/ops_nullfs.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: ops_nullfs.c,v 5.2.2.3 1992/08/02 10:42:21 jsp Exp $
+ * $Id: ops_nullfs.c,v 1.1.1.1 1998/11/05 02:04:50 ezk Exp $
*
*/
@@ -52,4 +52,4 @@
#include <am_defs.h>
#include <amd.h>
-/* FEEL FREE TO INPLEMENT THIS... :-) */
+/* FEEL FREE TO IMPLEMENT THIS... :-) */
diff --git a/contrib/amd/amd/ops_pcfs.c b/contrib/amd/amd/ops_pcfs.c
index e46b711..3ff67b1 100644
--- a/contrib/amd/amd/ops_pcfs.c
+++ b/contrib/amd/amd/ops_pcfs.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: ops_pcfs.c,v 5.2.2.1 1992/02/09 15:09:08 jsp beta $
+ * $Id: ops_pcfs.c,v 1.1.1.1 1998/11/05 02:04:50 ezk Exp $
*
*/
diff --git a/contrib/amd/amd/ops_tfs.c b/contrib/amd/amd/ops_tfs.c
index 97cd18c..44a0d11 100644
--- a/contrib/amd/amd/ops_tfs.c
+++ b/contrib/amd/amd/ops_tfs.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: ops_tfs.c,v 5.2.2.3 1992/08/02 10:42:21 jsp Exp $
+ * $Id: ops_tfs.c,v 1.1.1.1 1998/11/05 02:04:51 ezk Exp $
*
*/
@@ -52,4 +52,4 @@
#include <am_defs.h>
#include <amd.h>
-/* FEEL FREE TO INPLEMENT THIS... :-) */
+/* FEEL FREE TO IMPLEMENT THIS... :-) */
diff --git a/contrib/amd/amd/ops_tmpfs.c b/contrib/amd/amd/ops_tmpfs.c
index ce1b4fd..1fed46a 100644
--- a/contrib/amd/amd/ops_tmpfs.c
+++ b/contrib/amd/amd/ops_tmpfs.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: ops_tmpfs.c,v 5.2.2.3 1992/08/02 10:42:21 jsp Exp $
+ * $Id: ops_tmpfs.c,v 1.1.1.1 1998/11/05 02:04:51 ezk Exp $
*
*/
@@ -52,4 +52,4 @@
#include <am_defs.h>
#include <amd.h>
-/* FEEL FREE TO INPLEMENT THIS... :-) */
+/* FEEL FREE TO IMPLEMENT THIS... :-) */
diff --git a/contrib/amd/amd/ops_ufs.c b/contrib/amd/amd/ops_ufs.c
index 9883af1..bf18f6f 100644
--- a/contrib/amd/amd/ops_ufs.c
+++ b/contrib/amd/amd/ops_ufs.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: ops_ufs.c,v 5.2.2.1 1992/02/09 15:09:08 jsp beta $
+ * $Id: ops_ufs.c,v 1.1.1.1 1998/11/05 02:04:51 ezk Exp $
*
*/
diff --git a/contrib/amd/amd/ops_umapfs.c b/contrib/amd/amd/ops_umapfs.c
index b2dcd72..af139a7 100644
--- a/contrib/amd/amd/ops_umapfs.c
+++ b/contrib/amd/amd/ops_umapfs.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: ops_umapfs.c,v 5.2.2.3 1992/08/02 10:42:21 jsp Exp $
+ * $Id: ops_umapfs.c,v 1.1.1.1 1998/11/05 02:04:51 ezk Exp $
*
*/
@@ -52,4 +52,4 @@
#include <am_defs.h>
#include <amd.h>
-/* FEEL FREE TO INPLEMENT THIS... :-) */
+/* FEEL FREE TO IMPLEMENT THIS... :-) */
diff --git a/contrib/amd/amd/ops_unionfs.c b/contrib/amd/amd/ops_unionfs.c
index 24f7e1f..07f9eef 100644
--- a/contrib/amd/amd/ops_unionfs.c
+++ b/contrib/amd/amd/ops_unionfs.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: ops_unionfs.c,v 5.2.2.3 1992/08/02 10:42:21 jsp Exp $
+ * $Id: ops_unionfs.c,v 1.1.1.1 1998/11/05 02:04:51 ezk Exp $
*
*/
@@ -52,4 +52,4 @@
#include <am_defs.h>
#include <amd.h>
-/* FEEL FREE TO INPLEMENT THIS... :-) */
+/* FEEL FREE TO IMPLEMENT THIS... :-) */
diff --git a/contrib/amd/amd/ops_xfs.c b/contrib/amd/amd/ops_xfs.c
index 1b4aab4..acc555ba 100644
--- a/contrib/amd/amd/ops_xfs.c
+++ b/contrib/amd/amd/ops_xfs.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: ops_xfs.c,v 5.2.2.1 1992/02/09 15:09:08 jsp beta $
+ * $Id: ops_xfs.c,v 1.1.1.1 1998/11/05 02:04:51 ezk Exp $
*
*/
diff --git a/contrib/amd/amd/opts.c b/contrib/amd/amd/opts.c
index 294cdb7..907e55c 100644
--- a/contrib/amd/amd/opts.c
+++ b/contrib/amd/amd/opts.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: opts.c,v 5.2.2.4 1992/08/02 10:42:21 jsp Exp $
+ * $Id: opts.c,v 1.2 1998/12/27 06:24:48 ezk Exp $
*
*/
@@ -91,7 +91,7 @@ struct functable {
};
/*
- * FORWARD DEFINITSION:
+ * FORWARD DEFINITION:
*/
static int f_in_network(char *);
static int f_netgrp(char *);
@@ -106,7 +106,7 @@ static struct am_opts fs_static; /* copy of the options to play with */
static char NullStr[] = "<NULL>";
static char nullstr[] = "";
static char *opt_dkey = NullStr;
-static char *opt_host = hostname;
+static char *opt_host = nullstr; /* XXX: was the global hostname */
static char *opt_hostd = hostd;
static char *opt_key = nullstr;
static char *opt_keyd = nullstr;
@@ -1050,7 +1050,7 @@ expand_op(opt_apply *p, int sel_p)
}
/*
- * Check that the search was succesful
+ * Check that the search was successful
*/
if (!op->name) {
/*
@@ -1104,7 +1104,7 @@ out:
}
/*
- * Save the exansion
+ * Save the expansion
*/
*p->opt = strdup(expbuf);
}
@@ -1219,6 +1219,9 @@ eval_fs_opts(am_opts *fo, char *opts, char *g_opts, char *path, char *key, char
memset((voidp) vars, 0, sizeof(vars));
memset((voidp) fo, 0, sizeof(*fo));
+ /* set hostname */
+ opt_host = (char *) am_get_hostname();
+
/*
* Set key, map & path before expansion
*/
@@ -1260,7 +1263,7 @@ eval_fs_opts(am_opts *fo, char *opts, char *g_opts, char *path, char *key, char
ok = FALSE;
/*
- * Normalise remote host name.
+ * Normalize remote host name.
* 1. Expand variables
* 2. Normalize relative to host tables
* 3. Strip local domains from the remote host
diff --git a/contrib/amd/amd/restart.c b/contrib/amd/amd/restart.c
index 572df86..cd7d842 100644
--- a/contrib/amd/amd/restart.c
+++ b/contrib/amd/amd/restart.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: restart.c,v 5.2.2.2 1992/08/02 10:42:21 jsp Exp $
+ * $Id: restart.c,v 1.1.1.1 1998/11/05 02:04:49 ezk Exp $
*
*/
diff --git a/contrib/amd/amd/rpc_fwd.c b/contrib/amd/amd/rpc_fwd.c
index 7f3c59b..8f308b8 100644
--- a/contrib/amd/amd/rpc_fwd.c
+++ b/contrib/amd/amd/rpc_fwd.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: rpc_fwd.c,v 5.2.2.1 1992/02/09 15:09:01 jsp beta $
+ * $Id: rpc_fwd.c,v 1.1.1.1 1998/11/05 02:04:49 ezk Exp $
*
*/
diff --git a/contrib/amd/amd/sched.c b/contrib/amd/amd/sched.c
index ffbe2c8..a917c3c 100644
--- a/contrib/amd/amd/sched.c
+++ b/contrib/amd/amd/sched.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: sched.c,v 5.2.2.1 1992/02/09 15:09:02 jsp beta $
+ * $Id: sched.c,v 1.1.1.1 1998/11/05 02:04:49 ezk Exp $
*
*/
@@ -127,7 +127,7 @@ run_task(task_fun tf, voidp ta, cb_fun cf, voidp ca)
p->wchan = (voidp) p;
#ifdef HAVE_SIGACTION
- sigemptyset(&new); /* initialise signal set we wish to block */
+ sigemptyset(&new); /* initialize signal set we wish to block */
sigaddset(&new, SIGCHLD); /* only block on SIGCHLD */
sigprocmask(SIG_BLOCK, &new, &mask);
#else /* not HAVE_SIGACTION */
@@ -235,7 +235,7 @@ do_task_notify(void)
* Do callback if it exists
*/
if (p->cb_fun) {
- /* these two trigraphs will ensure compatibity with strict POSIX.1 */
+ /* these two trigraphs will ensure compatibility with strict POSIX.1 */
(*p->cb_fun) (WIFEXITED(p->w) ? WEXITSTATUS(p->w) : 0,
WIFSIGNALED(p->w) ? WTERMSIG(p->w) : 0,
p->cb_closure);
diff --git a/contrib/amd/amd/srvr_amfs_auto.c b/contrib/amd/amd/srvr_amfs_auto.c
index e77c591..df2ffdf 100644
--- a/contrib/amd/amd/srvr_amfs_auto.c
+++ b/contrib/amd/amd/srvr_amfs_auto.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: srvr_amfs_auto.c,v 5.2.2.1 1992/02/09 15:09:05 jsp beta $
+ * $Id: srvr_amfs_auto.c,v 1.1.1.1 1998/11/05 02:04:49 ezk Exp $
*
*/
OpenPOWER on IntegriCloud
diff --git a/contrib/amd/amd/amfs_auto.c b/contrib/amd/amd/amfs_auto.c
index e7f8589..c6421bf 100644
--- a/contrib/amd/amd/amfs_auto.c
+++ b/contrib/amd/amd/amfs_auto.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: amfs_auto.c,v 1.1 1997-1998/06/30 19:22:30 ezk Exp ezk $
+ * $Id: amfs_auto.c,v 1.1.1.1 1998/11/05 02:04:46 ezk Exp $
*
*/
@@ -477,7 +477,7 @@ try_mount(voidp mvp)
break
fi
if no error on this mount then
- this_error = initialise mount point
+ this_error = initialize mount point
fi
if no error on this mount and mount is delayed then
this_error = -1
@@ -496,7 +496,7 @@ try_mount(voidp mvp)
this_error = mount in foreground
fi
fi
- if an error occured on this mount then
+ if an error occurred on this mount then
update stats
save error in mount point
fi
@@ -657,7 +657,7 @@ amfs_auto_bgmount(struct continuation * cp, int mpe)
/*
* Will usually need to play around with the mount nodes
* file attribute structure. This must be done here.
- * Try and get things initialised, even if the fileserver
+ * Try and get things initialized, even if the fileserver
* is not known to be up. In the common case this will
* progress things faster.
*/
@@ -987,7 +987,7 @@ amfs_auto_lookuppn(am_node *mp, char *fname, int *error_return, int op)
}
/*
* If an error occured then return it.
*/
if (error) {
#ifdef DEBUG
@@ -1511,7 +1511,7 @@ amfs_auto_readdir_browsable(am_node *mp, nfscookie cookie, nfsdirlist *dp, nfsen
if (te_next) {
nfsentry *te_saved = te_next->ne_nextentry;
te_next->ne_nextentry = NULL; /* terminate "te" chain */
- te_next = te_saved; /* save rest of "te" for next interation */
+ te_next = te_saved; /* save rest of "te" for next iteration */
dp->dl_eof = FALSE; /* tell readdir there's more */
} else {
dp->dl_eof = TRUE; /* tell readdir that's it */
@@ -1565,7 +1565,7 @@ amfs_auto_readdir_browsable(am_node *mp, nfscookie cookie, nfsdirlist *dp, nfsen
if (te_next) {
nfsentry *te_saved = te_next->ne_nextentry;
te_next->ne_nextentry = NULL; /* terminate "te" chain */
- te_next = te_saved; /* save rest of "te" for next interation */
+ te_next = te_saved; /* save rest of "te" for next iteration */
dp->dl_eof = FALSE; /* tell readdir there's more */
}
ep = te; /* send next chunk of "te" chain */
@@ -987,7 +987,7 @@ amfs_auto_lookuppn(am_node *mp, char *fname, int *error_return, int op)
}
/*
- * If an error occured then return it.
+ * If an error occurred then return it.
*/
if (error) {
diff --git a/contrib/amd/amd/ops_autofs.c b/contrib/amd/amd/ops_autofs.c
index 14ab415..91015b0 100644
--- a/contrib/amd/amd/ops_autofs.c
+++ b/contrib/amd/amd/ops_autofs.c
@@ -17,7 +17,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
+ * must display the following acknowledgment:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
@@ -38,7 +38,7 @@
*
* %W% (Berkeley) %G%
*
- * $Id: ops_autofs.c,v 5.2.2.3 1992/08/02 10:42:21 jsp Exp $
+ * $Id: ops_autofs.c,v 1.2 1998/12/27 06:24:47 ezk Exp $
*
*/
@@ -53,7 +53,7 @@
#include <amd.h>
/*
- * CLUDGE: wrap whole file in HAVE_FS_AUTOFS, becasue
+ * KLUDGE: wrap whole file in HAVE_FS_AUTOFS, because
* not all systems with an automounter file system are supported
* by am-utils yet...
*/
@@ -76,7 +76,7 @@ static int mount_autofs(char *dir, char *opts);
static int autofs_mount_1_svc(struct mntrequest *mr, struct mntres *result, struct authunix_parms *cred);
static int autofs_unmount_1_svc(struct umntrequest *ur, struct umntres *result, struct authunix_parms *cred);
-/* externam declarations */
+/* external declarations */
extern bool_t xdr_mntrequest(XDR *, mntrequest *);
extern bool_t xdr_mntres(XDR *, mntres *);
extern bool_t xdr_umntrequest(XDR *, umntrequest *);
@@ -284,8 +284,9 @@ mount_autofs(char *dir, char *opts)
/*
* Make a ``hostname'' string for the kernel
*/
- sprintf(fs_hostname, "pid%ld@%s:%s", (long) (foreground ? mypid : getppid()),
- hostname, dir);
+ sprintf(fs_hostname, "pid%ld@%s:%s",
+ (long) (foreground ? am_mypid : getppid()),
+ am_get_hostname(), dir);
/*
* Most kernels have a name length restriction.
@@ -481,7 +482,7 @@ out:
break
fi
if no error on this mount then
- this_error = initialise mount point
+ this_error = initialize mount point
fi
if no error on this mount and mount is delayed then
this_error = -1
@@ -500,7 +501,7 @@ out:
this_error = mount in foreground
fi
fi
- if an error occured on this mount then
+ if an error occurred on this mount then
update stats
save error in mount point
fi
@@ -661,7 +662,7 @@ autofs_bgmount(struct continuation * cp, int mpe)
/*
* Will usually need to play around with the mount nodes
* file attribute structure. This must be done here.
- * Try and get things initialised, even if the fileserver
+ * Try and get things initialized, even if the fileserver
* is not known to be up. In the common case this will
* progress things faster.
*/
@@ -711,7 +712,7 @@ autofs_bgmount(struct continuation * cp, int mpe)
cp->retry = TRUE;
}
- if (!this_error)
+ if (!this_error) {
if (p->fs_flags & FS_MBACKGROUND) {
mf->mf_flags |= MFF_MOUNTING; /* XXX */
#ifdef DEBUG
@@ -737,6 +738,7 @@ autofs_bgmount(struct continuation * cp, int mpe)
cp->retry = TRUE;
}
}
+ }
if (this_error >= 0) {
if (this_error > 0) {
@@ -859,7 +861,7 @@ autofs_lookuppn(am_node *mp, char *fname, int *error_return, int op)
char *auto_opts; /* Automount options */
int error = 0; /* Error so far */
char path_name[MAXPATHLEN]; /* General path name buffer */
- char apath[MAXPATHLEN]; /* authofs path (added space) */
+ char apath[MAXPATHLEN]; /* autofs path (added space) */
char *pfname; /* Path for database lookup */
struct continuation *cp; /* Continuation structure if need to mount */
int in_progress = 0; /* # of (un)mount in progress */
@@ -877,10 +879,11 @@ autofs_lookuppn(am_node *mp, char *fname, int *error_return, int op)
*/
if (amd_state == Finishing) {
#ifdef DEBUG
- if ((mf = mp->am_mnt) == 0 || mf->mf_ops == &amfs_direct_ops)
+ if ((mf = mp->am_mnt) == 0 || mf->mf_ops == &amfs_direct_ops) {
dlog("%s mount ignored - going down", fname);
- else
+ } else {
dlog("%s/%s mount ignored - going down", mp->am_path, fname);
+ }
#endif /* DEBUG */
ereturn(ENOENT);
}
@@ -990,7 +993,7 @@ autofs_lookuppn(am_node *mp, char *fname, int *error_return, int op)
}
/*
* If an error occured then return it.
*/
if (error) {
#ifdef DEBUG
@@ -990,7 +993,7 @@ autofs_lookuppn(am_node *mp, char *fname, int *error_return, int op)
}
/*
- * If an error occured then return it.
+ * If an error occurred then return it.
*/
if (error) {